;****************************************************************************
;
;                              E V 1 4 . 0 4 3
;
;                       C U S T O M E R   E Q U A T E S
;
;                             1 1   J a n   9 6
;
;  When making changes to the formula entries below, only change the integer
;  value.  Do not remove or change the curly braces {} contained in any of
;  the formulas.  They are required for the assembler.

;****************************************************************************
;  These constants are the scaling factors used to formulate set and trip
;  points, multiplied by either VOLTS_MULTIPLY or AMPS_MULTIPLY.  To determine
;  the proper settings, first assemble the program and then start the charging
;  process.  Next, determine the voltage and current readings from the
;  diagnostic program.  Then take actual measurements for both voltage and
;  current.  The following formula may then be used to determine the new
;  calibration settings:
;
;                       Diagnostic Displayed Reading
; New Calib Setting =   -----------------------------  * Present Scaling Factor
;                          Actual Measured Reading
;
;     Default Setting for Voltage = 4867  ;   .4867 * 10000
;     Default Setting for Current = 1050  ; 10.50   * 100
;
VOLTS_SCALE:    equ     4867              ;   .4867 * 10000
;
AMPS_SCALE:     equ     1050              ; 10.50   * 100

;****************************************************************************
;
;                    B A T T E R Y   I N F O R M A T I O N
;
;  Battery.  This defines the total number of batteries in series for this
;  vehicle.  Packs defines the number of parallel strings within the battery
;  pack.  Cells defines the number of cells per battery.
;
;     Battery Type Conversion Table
;
;        Type Battery 0  = Type Of Battery Unknown or Not Listed Below
;        Type Battery 1  = Gates (SLA) G12V38AH
;        Type Battery 2  = Gates (SLA) G12V26AH
;        Type Battery 3  = GNB (SLA) Upsolyte
;        Type Battery 4  = GNB (SLA) Evolyte
;        Type Battery 5  = GNB (SLA) Champion
;        Type Battery 6  = Sonnenshein (SLA)
;        Type Battery 7  = Trojan TEB225
;        Type Battery 8  = Genesis (SLA) G12V38AH10C
;        Type Battery 9  = Electrosource 12N95
;        Type Battery 10 = Ovonic OVC12 Nickel Metal Hydride
;
;     Valid Range = 1 - 255
;
TYPE_BATTERY:   equ     0                 ;Battery Type Unknown
BATTERIES:      equ     27                ;Number of batteries in series
STRINGS:        equ     4                 ;Number of strings in pack
CELLS:          equ     6                 ;Number of cells per battery
AMP_HOURS:      equ     85                ;Amphour capacity of Battery Pack

;  Battery pack maximum voltage allowed for this vehicle.  Any voltage above
;  this value will terminate the charging process.
;
;     Valid Range    =  0 - 500 VDC
;     Normal Value   =  (2.8 vpc) (Number of Cells) ( Number of Batteries)
;     Default Value  =  400
;
VMAX:           equ     {400*VOLTS_SCALE}/VOLTS_MULTIPLY

;  Battery pack minimum voltage allowed for this vehicle.  Any voltage below
;  this point will inhibit charging.
;
;     Valid Range    =  0 - 500 VDC
;     Normal Value   =  (1.66 vpc) (Number of Cells) ( Number of Batteries)
;
VMIN:           equ     {260*VOLTS_SCALE}/VOLTS_MULTIPLY

;****************************************************************************
;  Power Up Delay.  This is the amount of time delay after connection present
;  is detected until the charging process begins.
;
;     Valid Range   = 0 - 59 seconds
;     Default Value = 10 seconds
;
PUD:            equ     10                ;Power up delay

;  Time Maximum.  This is the maximum amount of charging time allowed, in
;  hours, for all modes combined.  If the system clock exceeds this time limit,
;  the charge controller will enter Mode 6.
;
;     Valid Range   = 0 - 255 Hours
;     Default Value = 24 hours
;
TMAX:           equ     24                ;Total Maximum system charging time

;****************************************************************************


;****************************************************************************
;  The charging process allows for 4 different Modes.  Effective with EV14, the
;  Mode sequence may be determined by the customer.  Based on the constants
;  listed below, set the sequence in each respective constant.
;
FIRST_MODE:     equ     1                 ;Process this Mode first.
SECOND_MODE:    equ     2                 ;Process this Mode second.
THIRD_MODE:     equ     3                 ;Process this Mode third.
FOURTH_MODE:    equ     4                 ;Process this Mode fourth.

;****************************************************************************
;
;                    M O D E   1   P A R A M E T E R S
;
;  Mode 1 Current Set Point.  This is the charging amperage that should be
;  maintained while in Mode 1.  Entries must be integer numbers.  Multiply the
;  required entry by a factor of 10 before entering.  For instance, if the
;  desired amperage is 15, an entry of 150 (15 * 10) is required.  To set 12.7
;  amps, enter 127 (12.7 * 10).
;
;     Valid Range = 0 - 200 where 200 = 20.0 Amps
;
I1:             equ     {{0*AMPS_SCALE}/{AMPS_MULTIPLY*Ten}}

;  Mode 1 Voltage Trip Point.  This is the voltage that will cause the charge
;  controller to trip from Mode 1 into Mode 2.
;
;     Valid Range = 0 - 500 VDC
;
VTRIP1:         equ     {0*VOLTS_SCALE}/VOLTS_MULTIPLY
 
;  Mode 1 Time in Hours and Minutes.  This is the maximum amount of charging
;  time allowed, in hours and minutes for Mode 1.
;
;     Valid Range = 0 - 24 Hours
;     Valid Range = 0 - 59 Minutes
;
T1_HOURS:       equ     0                 ;Mode 1 timeout in hours
T1_MIN:         equ     0                 ;Mode 1 timeout in minutes

;****************************************************************************
;
;                    M O D E   2   P A R A M E T E R S
;
;  Mode 2 Voltage Set Point.  This is the charging voltage that should be
;  maintained while in Mode 2.
;
;     Valid Range = 0 - 500 VDC
;
V1:             equ     {0*VOLTS_SCALE}/VOLTS_MULTIPLY
 
;  Mode 2 Current Trip Point.  This is the amperage that will cause the charge
;  controller to trip from Mode 2 into Mode 3.  Entries must be integer
;  numbers.  Multiply the required entry by a factor of 10 before entering.
;  For instance, if the desired amperage is 15, an entry of 150 (15 * 10) is
;  required.  To set 12.7 amps, enter 127 (12.7 * 10).
;
;     Valid Range = 0 - 200 where 200 = 20.0 Amps
;
ITRIP1:         equ     {{0*AMPS_SCALE}/{AMPS_MULTIPLY*Ten}}
 
;  Mode 2 Maximum Current (IMax_Mode2).  This is the maximum amount of current
;  which may be applied during Mode 2.  Prevents current from running wild.
;
;     Valid Range    = 0 - 200 where 200 = 20.0 Amps
;     Normal Value   = Value used for I1 setting from Mode 1 if using Mode 1.
;                    = 200 (where 200 = 20.0 Amps) if NOT using Mode 1.
;
IMAX_MODE2:     equ     {{0*AMPS_SCALE}/{AMPS_MULTIPLY*Ten}}

;  Mode 2 Time in Hours and Minutes.  This is the maximum amount of charging
;  time allowed, in hours and minutes for Mode 2.
;
;     Valid Range = 0 - 24 Hours
;     Valid Range = 0 - 59 Minutes
;
T2_HOURS:       equ     0                 ;Mode 2 timeout in hours
T2_MIN:         equ     0                 ;Mode 2 timeout in minutes
 
;****************************************************************************
;
;                    M O D E   3   P A R A M E T E R S
;
;  Mode 3 Current Set Point.  This is the charging amperage that should be
;  maintained while in Mode 3.  Entries must be integer numbers.  Multiply the
;  required entry by a factor of 10 before entering.  For instance, if the
;  desired amperage is 15, an entry of 150 (15 * 10) is required.  To set 12.7
;  amps, enter 127 (12.7 * 10).
;
;     Valid Range = 0 - 200 where 200 = 20.0 Amps
;
I2:             equ     {{0*AMPS_SCALE}/{AMPS_MULTIPLY*Ten}}

;  Number of Levels in which Mode 3 will operate.  For each level entered,
;  a percentage of the I2 value will be used for the current level.  An example
;  would be if I2 is set for 1.0 amps, Levels is set to 10, then the first
;  level of Mode 3 would be 1 amp, the 2nd level of Mode 3 would be .9 amps,
;  the 3rd level of Mode 3 would be .8 amps, etc..  Each change to the original
;  I2 value is calculated by I2/Levels.  In our example, 1.0/10 = .1amp
;  reduction for each level.  Set Levels to 1 if a normal constant current mode
;  is desired.
;
;     Valid Range    = 1 - 10 Levels
;     Default Value  = 1 Level
;
LEVELS:         equ     1                 ;Number of Levels for Mode 3

;  Mode 3 Voltage Trip Point.  This is the voltage that will cause the charge
;  controller to trip from Mode 3 into Mode 4.
;
;     Valid Range = 0 - 500 VDC
;
VTRIP2:         equ     {0*VOLTS_SCALE}/VOLTS_MULTIPLY
 
;  Mode 3 Time in Hours and Minutes.  This is the maximum amount of charging
;  time allowed, in hours and minutes for Mode 3.
;
;     Valid Range = 0 - 24 Hours
;     Valid Range = 0 - 59 Minutes
;
T3_HOURS:       equ     0                 ;Mode 3 timeout in hours
T3_MIN:         equ     0                 ;Mode 3 timeout in minutes
 
;****************************************************************************
;
;                    M O D E   4   P A R A M E T E R S
;
;  Mode 4 Voltage Set Point.  This is the charging voltage that should be
;  maintained while in Mode 4.
;
;     Valid Range = 0 - 500 VDC
;
V2:             equ     {0*VOLTS_SCALE}/VOLTS_MULTIPLY

;  Mode 4 Current Trip Point.  This is the amperage that will cause the charge
;  controller to trip from Mode 4 into Mode 5.  Entries must be integer
;  numbers.  Multiply the required entry by a factor of 10 before entering.
;  For instance, if the desired amperage is 15, an entry of 150 (15 * 10) is
;  required.  To set 12.7 amps, enter 127 (12.7 * 10).
;
;     Valid Range = 0 - 200 where 200 = 20.0 Amps
;
ITRIP2:         equ     {{0*AMPS_SCALE}/{AMPS_MULTIPLY*Ten}}

;  Mode 4 Maximum Current (IMax_Mode4).  This is the maximum amount of current
;  which may be applied during Mode 4.  Prevents current from running wild.
;
;     Valid Range    = 0 - 200 where 200 = 20.0 Amps
;     Normal Value   = Value used for I2 setting from Mode 3 if using Mode 3.
;                    = 25 (where 25 = 2.5 Amps) per battery string if NOT using
;                      Mode 3.
;
IMAX_MODE4:     equ     {{0*AMPS_SCALE}/{AMPS_MULTIPLY*Ten}}

;  Mode 4 Time in Hours and Minutes.  This is the maximum amount of charging
;  time allowed, in hours and minutes for Mode 4.
;
;     Valid Range = 0 - 24 Hours
;     Valid Range = 0 - 59 Minutes
;
T4_HOURS:       equ     0                 ;Mode 4 timeout in hours
T4_MIN:         equ     0                 ;Mode 4 timeout in minutes

;******************************************************************************
;  Temperature Sensor Monitoring
;
;  Temperature sensors are normally installed in the battery pack area to
;  assist in thermal management of the batteries.  If this constant is set to a
;  one (1), the temperature sensors will be enabled.  If set to a zero (0), no
;  monitoring of the temperature sensors will occur.  Set this flag to 1 only
;  if the additional hardware for temperature sensors has been installed in the
;  vehicle.
;
;     Valid Range    =  0 = Don't perform Temperature Sensor monitoring.
;                    =  1 = Do perform Temperature Sensor monitoring.
;     Default Value  =  0 = Don't perform Temperature Sensor monitoring.
;
MON_TEMP_SENSE: equ     0                 ;Don't Monitor Temperature Sensors

;******************************************************************************
;  TempMax defines the maximum temperature (in Kelvin) allowed to be detected
;  by the temperature sensors.  If this value is exceeded, Fault Mode is
;  entered.
;
;     Valid Range    = 243 - 348 degrees Kelvin
;     Normal Value   = 348 degrees Kelvin
;     Default Value  = 348 degrees Kelvin
;
TEMPMAX:        equ     {{{{348*LSB_PER_KELVIN}-{243*LSB_PER_KELVIN}}+50}/100}
                                          ;range = -30 C  to +75 C
                                          ;      = 243 K  to 348 K
                                          ;348 = 348 degrees kelvin
                                          ;348 K * 2.11 lsb/K - 523.77 = 210
                                          ;LSB_PER_KELVIN defined in equates.h
                                          ;243 = Min Kelvin temp read by sensor
                                          ;50 = .5 * 100 for rounding integer
                                          ;100 = offset used on LSB_PER_KELVIN
                                          ; to make it an integer.

;****************************************************************************
;  TempMin defines the minimum temperature (in Kelvin) allowed to be detected
;  by the temperature sensors.  If temperature drops below this value, Fault
;  Mode is entered.
;
;     Valid Range    = 243 - 348 degrees Kelvin
;     Normal Value   = 253 degrees Kelvin
;     Default Value  = 253 degrees Kelvin
;
TEMPMIN:        equ     {{{{253*LSB_PER_KELVIN}-{243*LSB_PER_KELVIN}}-50}/100}
                                          ;range = -30 C  to +75 C
                                          ;      = 243 K  to 348 K
                                          ;253 = 253 degrees kelvin
                                          ;253 K * 2.11 lsb/K - 512.73 = 20
                                          ;LSB_PER_KELVIN defined in equates.h
                                          ;243 = Min Kelvin temp read by sensor
                                          ;50 = .5 * 100 for rounding integer
                                          ;100 = offset used on LSB_PER_KELVIN
                                          ; to make it an integer.

;****************************************************************************
;
;              T E M P E R A T U R E   C O M P E N S A T I O N
;
;  Temperature Compensation Flag.  This constant should be set to a 1 (one) if
;  temperature compensation is desired.  If not desired, set this constant to
;  0 (zero).  Compensation can only work if temperature sensors are installed.
;
;     Valid Range    =  0 = Don't perform temperature compensation
;                       1 = Do perform temperature compensation
;     Default Value  =  0 = Don't perform temperature compensation
;
TEMP_COMP_FLAG: equ     0                 ;0 = No Temperature Compensation

;  Temperature Compensation Maximum and Minimum Voltages.  These constants
;  define voltage limits for the temperature compensation routines.  Voltage
;  should not exceed Temp_Max_Volts nor drop below Temp_Min_Volts.  Note: The
;  values set below are ignored if temperature compensation is not enabled.
;  TEMP_MAX_VOLTS should not be set above VMAX.
;
;     Valid Range = 0 - 500 VDC
;     Normal Max Value = (2.5 vpc) (Number of Cells) ( Number of Batteries)
;     Normal Min Value = (2.2 vpc) (Number of Cells) ( Number of Batteries)
;
TEMP_MAX_VOLTS: equ     {410*VOLTS_SCALE}/VOLTS_MULTIPLY
TEMP_MIN_VOLTS: equ     {352*VOLTS_SCALE}/VOLTS_MULTIPLY

;  Temperature Compensation required per cell, per degree celsius.  This
;  constant is then used when determining the required offset voltage.  When
;  entering values, the value must be integer, and not preceeded by a zero.
;  The value represents millivolts per cell, per degree celsius.
;
;     Valid Range   = 0 - 999 where 999 equals 9.99mv per cell per degree C.
;     Default Value = 444                 ;Lead Acid Battery
;
TEMP_COMP_MV:   equ     444               ;4.44mv per cell

;  Temperature which is considered Nominal for the batteries used in this EV
;  application.  Temperature compensation will be calculated based on this
;  nomimal temperature.
;
;     Default Value = 25 degrees C        ;Lead Acid Battery
;
TEMP_NOMINAL_C: equ     25                ;Degrees Celsius

;****************************************************************************
;  Gain factors for calculating error offsets during the control routines.
;
I_COR:          equ     1                 ; scaled constant current gain (Kcc)
                                          ; range = 0 - 128
 
V_COR:          equ     4                 ; scaled constant voltage gain (Kcv)
                                          ; range = 0 - 248

;****************************************************************************
;
;  Special Flags and Variables for specific installations
;
;****************************************************************************
;
;  Amp Hour Tracking 2
;
;  Mode 1 Amp Hour Tracking Counter Required. This flag signifies a requirement
;  to count the amp hours applied during Mode 1.  In-turn, the amp hours are
;  then used to control an additional trip point for Mode 2, based on the label
;  AMPHR_TRIP_2.  Note: If this flag is set, AMPHR_TRIP_2 MUST have a value
;  to work properly.
;
;     Valid Range    =  0 = Don't perform Mode 1 Amp Hour tracking
;                       1 = Do perform Mode 1 Amp Hour tracking
;     Default Value  =  0 = Don't perform Mode 1 Amp Hour tracking
;
AMPHR_TRACK_2:  equ     0                 ;Don't perform Mode 1 AmpHr tracking.

;  Mode 2 Amp Hour Trip Point.  This value represents the percentage of amp
;  hours tracked during Mode 1, to be used as an additional trip point for
;  exiting Mode 2.  Note: The value set below is ignored if Amp Hour Tracking
;  is not enabled and Mode 1 MUST be processed prior to Mode 2.
;
;     Valid Range    =  1 - 100 percent.
;     Normal Value   =  20 percent
;     Default Value  =  20 percent
;
AMPHR_TRIP_2:   equ     20                ;Percent of amp hours applied during
                                          ;Mode 1 to use as a trip point out
                                          ;of Mode 2.

;****************************************************************************
;
;  Amp Hour Tracking 3
;
;  Mode 1 and Mode 2 Amp Hour Tracking Counter Required. This flag signifies a
;  requirement to count the cumulative amp hours applied during Modes 1 and 2.
;  In-turn, the amp hours are then used to control an additional trip point for
;  Mode 3, based on the label AMPHR_TRIP_3.  Note: If this flag is set,
;  AMPHR_TRIP_3 MUST have a value to work properly.
;
;     Valid Range    =  0 = Don't perform Mode 1 & Mode 2 Amp Hour tracking
;                       1 = Do perform Mode 1 & Mode 2 Amp Hour tracking
;     Default Value  =  0 = Don't perform Mode 1 & Mode 2 Amp Hour tracking
;
AMPHR_TRACK_3:  equ     0                 ;Don't track Mode 1&2 AmpHrs for trip

;  Mode 2 Amp Hour Trip Point.  This value represents the percentage of the
;  cumulative amp hours tracked during Modes 1 and 2, to be used as an
;  additional trip point for exiting Mode 3.  Note: The value set below is
;  ignored if AMPHR_TRACK_2 is not enabled and Modes 1 AND 2 MUST be processed
;  prior to Mode 3.
;
;     Valid Range    =  1 - 100 percent.
;     Normal Value   =  20 percent
;     Default Value  =  20 percent
;
AMPHR_TRIP_3:   equ     20                ;Percent of cumulative amp hours
                                          ; applied during Mode 1 and Mode 2 to

;  Amp Hour Maximum Limit represents the maximum cumulative amphours allowed to
;  be returned to the battery pack during this charging cycle.  If this limit
;  is exceeded during the charging cycle, Fault Mode is entered.
;
;     Valid Range    =  10% - 200% of Battery Pack AmpHour Capacity
;     Normal Value   =  130% of Battery Pack AmpHour Capacity.
;
AMPHR_MAXLIMIT: equ     {{130*AMP_HOURS}+50}/100   ;Cumulative Maximum AmpHours
                                                   ; which may be applied

;****************************************************************************
;  The Bypass_TripPt flag indicates the trip points for Mode 2 & Mode 4 are to
;  be ignored.  This will then cause Mode 2 & Mode 4 to operate until the time
;  settings in (T2_HOURS + T2_MIN) and (T4_HOURS + T4_MIN) have elapsed for
;  their respective modes.
;
;     Valid Range    =  0 = Don't bypass Mode 2 & Mode 4 trip points.
;                    =  1 = Do bypass Mode 2 & Mode 4 trip points.
;     Default Value  =  0 = Don't bypass Mode 2 & Mode 4 trip points.
;
BYPASS_TRIPPT:  equ     0                 ;Don't bypass Mode 2 & 4 Trip Points

;****************************************************************************
;
;                      E N D   O F   C U S T O M E R . H
;
;****************************************************************************
